==> activity-custom-center-api-1.0.19-20240920.081416-27-sources.jar: cn/com/duiba/activity/custom/center/api/dto/wandav1/distribution/DistributeDto.java <==
package cn.com.duiba.activity.custom.center.api.dto.wandav1.distribution;

import java.io.Serializable;
import java.util.List;

/**
 * @Description 分销信息
 * @Author huliangsheng
 * @Date 2024/9/11 16:25
 */
public class DistributeDto implements Serializable {

    private static final long serialVersionUID = 8626947177000260679L;
    /**
     * 分销号
     */
    private String disNo;

    /**
     * 分销员姓名
     */
    private String disName;

    /**
     * 手机号
     */
    private String mobile;

    /**
     * 获得的积分值
     */
    private Integer credits;

    /**
     * 分销人员身份 1-员工
     */
    private String disIdentity;

    /**
     * CEMID
     */
    private String cemId;

    /**
     * 归属
     */
    private List<HotelDto> hotelList;

    public List<HotelDto> getHotelList() {
        return hotelList;
    }

    public void setHotelList(List<HotelDto> hotelList) {
        this.hotelList = hotelList;
    }

    public String getDisNo() {
        return disNo;
    }

    public void setDisNo(String disNo) {
        this.disNo = disNo;
    }

    public String getDisName() {
        return disName;
    }

    public void setDisName(String disName) {
        this.disName = disName;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public Integer getCredits() {
        return credits;
    }

    public void setCredits(Integer credits) {
        this.credits = credits;
    }

    public String getDisIdentity() {
        return disIdentity;
    }

    public void setDisIdentity(String disIdentity) {
        this.disIdentity = disIdentity;
    }

    public String getCemId() {
        return cemId;
    }

    public void setCemId(String cemId) {
        this.cemId = cemId;
    }
}

==> activity-custom-center-api-1.0.21-sources.jar: cn/com/duiba/activity/custom/center/api/dto/wandav1/distribution/DistributeDto.java <==
package cn.com.duiba.activity.custom.center.api.dto.wandav1.distribution;

import java.io.Serializable;

/**
 * @Description 分销信息
 * @Author huliangsheng
 * @Date 2024/9/11 16:25
 */
public class DistributeDto implements Serializable {

    private static final long serialVersionUID = 8626947177000260679L;
    /**
     * 分销号
     */
    private String disNo;

    /**
     * 分销员姓名
     */
    private String disName;

    /**
     * 手机号
     */
    private String mobile;

    /**
     * 获得的积分值
     */
    private int credits;

    /**
     * 分销人员身份 1-员工
     */
    private String disIdentity;

    /**
     * CEMID
     */
    private String cemId;

    /**
     * 酒店code
     */
    private String hotelCode;

    /**
     * 酒店
     */
    private String hotel;

    /**
     * 归属
     */
    private String department;

    public String getHotelCode() {
        return hotelCode;
    }

    public void setHotelCode(String hotelCode) {
        this.hotelCode = hotelCode;
    }

    public String getHotel() {
        return hotel;
    }

    public void setHotel(String hotel) {
        this.hotel = hotel;
    }

    public String getDepartment() {
        return department;
    }

    public void setDepartment(String department) {
        this.department = department;
    }

    public String getDisNo() {
        return disNo;
    }

    public void setDisNo(String disNo) {
        this.disNo = disNo;
    }

    public String getDisName() {
        return disName;
    }

    public void setDisName(String disName) {
        this.disName = disName;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public int getCredits() {
        return credits;
    }

    public void setCredits(int credits) {
        this.credits = credits;
    }

    public String getDisIdentity() {
        return disIdentity;
    }

    public void setDisIdentity(String disIdentity) {
        this.disIdentity = disIdentity;
    }

    public String getCemId() {
        return cemId;
    }

    public void setCemId(String cemId) {
        this.cemId = cemId;
    }
}
